@@ -11,7 +11,7 @@ c           configuration of detector
         parameter (maxcom = EPMAX_COMMENT)
 
 
- 
+        logical  Incused      ! #inc is used or not
 	integer ncmax         ! max components
         parameter ( ncmax = MAX_COMPONENT )
 c((((((((((
@@ -176,7 +176,7 @@ c
      4  CnArea, comflag, CnCounter, AttrCounter, NVTX,
      5  coment, Nequates, cumsubdloc,
      6  Nfield, NsubD,  mode, SubDUsed, wrtcom, comcounter,
-     7  comloc, EqualFshort
+     7  comloc, Incused,  EqualFshort
 
         common /Zcnfic/ confdata, comarea, Field, FieldAsItis,
      *    SubDName, EqName, form
