@@ -1,17 +1,23 @@
+        integer Ioprim       ! primary container.  code subcode ...etc
+        integer Inpxyz, Inpdir, Inperg, Inpsubcode, Inptime, 
+     *  Inp1ry, Inpmul
 	integer IoCont, Ir1,  Nevent
 	real*8  JobTime, BaseTime
         character*8 pdatE0, ptimE0, Ddate, DeadLine
         character*256 EpicsFile, SepicsFile, ConfigFile
         character*256  PrimaryFile
 
+       parameter(  Ioprim=15 )
 c             sepics common
          common /ZsepManegc/ EpicsFile, SepicsFile, ConfigFile,
      *  PrimaryFile,
      *  ptimE0,  pdatE0, Ddate, DeadLine
 
          common /ZsepManeg/ BaseTime,
-     3   IoCont, JobTime,
-     4   Ir1(2), Nevent
+     *   IoCont, JobTime,
+     *   Ir1(2), Nevent,
+     *   Inpxyz, Inpdir, Inperg, Inpsubcode, Inptime, Inp1ry,
+     *   Inpmul
 
 c
 c IoCont: fortran dev # for cont dataset.
@@ -22,3 +28,10 @@ c ptimE0: //                      time
 c
 
 
+
+ 
+
+
+
+       
+
