@@ -29,7 +29,6 @@ c      ****************
        subroutine sopen
        implicit none
 c              read control parameters
-#include  "ZepManager.h"
 #include  "ZsepManager.h"
 #include  "ZepDirec.h"
 #include  "ZepTrackp.h"
@@ -65,8 +64,10 @@ c                   init epics
         endif
 c              incident energy sampling. initializaiton 
         if( PrimaryFile(1:1) .eq. "+") then
+           Inp1ry = 1
            call siniPrim(PrimaryFile)
         else
+           Inp1ry = 0
            Inpxyz = 0
            Inpdir = 0
            Inperg  = 0
@@ -122,13 +123,18 @@ c         ---------------- Error -----------------
        end
        subroutine  siniPrim(file)
        implicit none
-#include  "ZepManager.h"
+#include  "ZsepManager.h"
        character(*) file
-       character*30  inpcond
+       character*50  inpcond
        integer klena,icon
 
        open(Ioprim, file=file(1:klena(file) ))
        read(Ioprim, '(a)')  inpcond
+       if( index(inpcond, "mul") .gt. 0 ) then
+          Inpmul = 1
+       else
+          Inpmul = 0
+       endif
        if( index(inpcond, "xyz") .gt. 0  ) then
           Inpxyz = 1
        else
@@ -164,26 +170,37 @@ c         ---------------- Error -----------------
        endif
 
        end
-       subroutine ssetip2( aTrack, icon)
+       subroutine ssetip3( aTrack, icon)
        implicit none
-#include  "ZepManager.h"
+#include  "ZsepManager.h"
 #include  "ZepTrack.h"
 #include  "Zcode.h"
        record /epTrack/ aTrack
-       integer icon, nf, fc
+       integer  icon  ! output. 0  -- go ahead.   1-- call  this again to set multiple 1ries
+c                      -1--> EOF
+       integer  nf, fc
        integer code, subcode, chg 
        real*8 erg, xin, yin, zin, wx, wy, wz, u, norm
        character*80 buf
        character*20 field(11)
 
+ 10    continue
        buf = ' '
        subcode = 0
 
        read(Ioprim, '(a)', end= 100 )  buf
 
        call kgetField(buf, field, 11, nf)
+       if(nf .eq. 0 )  then
+          if( Inpmul .eq. 1) then
+             icon = 1
+             return             !****************
+          else
+c            neglect blank line          
+             goto 10
+          endif
+       endif
 
-       
        fc = 1
        read(field(fc), *) code
        if(Inpsubcode .eq. 1) then
@@ -213,7 +230,7 @@ c         ---------------- Error -----------------
           read( field(fc), *)   wz
 c              the acuracy of input data may not be enough
           norm = sqrt( wx**2 + wy**2 + wz**2 )
- 1        wx = wx/norm
+          wx = wx/norm
           wy = wy/norm
           wz = wz/norm
        endif
@@ -266,12 +283,11 @@ c         nf many not be equal to fc. but must be nf >= fc
        endif
        icon = 0
        return
- 100   icon = 1
+ 100   icon = -1
        end
 
        subroutine  s1set(icon)
        implicit none
-#include  "ZepManager.h"
 #include  "ZsepManager.h"
 #include  "ZepPos.h"
 #include  "ZepDirec.h"
@@ -352,7 +368,23 @@ c      *****************
        end
       subroutine ssetip( icon )
       implicit none
-#include  "ZepManager.h"
+#include  "ZsepManager.h"
+      integer icon  !  output.  0
+      icon = 0
+      if( Inpmul .eq. 1) then
+c            multiple particles are incident; icon = 1--> end of a bunch
+         do while ( icon .eq. 0 )
+            call ssetip2( icon )
+         enddo
+         if(icon .eq. 1) icon = 0
+      else
+         call ssetip2( icon )
+      endif
+      end
+
+      subroutine ssetip2( icon )
+      implicit none
+
 #include  "ZsepManager.h"
 #include  "ZepTrackp.h"
 #include  "ZepTrack.h"
@@ -372,12 +404,12 @@ c      *****************
 
 c             set incident ptcl
 c               fix energy (momentum yet)
-      if(Inperg .eq. 0) then
+      if(Inp1ry .eq. 0 ) then
          call sfixe(aTrack)
          icon = 0
       else
-         call ssetip2(aTrack, icon)
-         if(icon .ne. 0) return ! ************
+         call ssetip3(aTrack, icon)
+         if(icon .ne. 0) return ! ************ EOF or end of 1 bunch of incidents
       endif
 
 c               fix position
@@ -490,7 +522,7 @@ c             get  current random no.
        end
       subroutine sfixe(aTrack)
        implicit none
-#include  "ZepManager.h"
+#include  "ZsepManager.h"
 #include  "Zglobalc.h"
 #include  "ZepTrack.h"
 #include  "ZepTrackp.h"
@@ -694,7 +726,7 @@ c              direct the angle around the normal vector
 c        ***************************
         entry sfixo(aTrack)
 c              fix time of incidence
-        if( Inptime .eq. 0) then
+        if( Inptime .eq. 0 ) then
            aTrack.t = 0.d0
         endif
 c           fix momentum 
